==> plantuml-libs-6.0.0.tgz: package/distribution/aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService.md <==
# AwsIoTAlexaVoiceService


```text
aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService
```

```text
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')
```



| Illustration | AwsIoTAlexaVoiceService | AwsIoTAlexaVoiceServiceCard | AwsIoTAlexaVoiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService.png) | ![illustration for AwsIoTAlexaVoiceService](../../../aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceCard](../../../aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceServiceCard.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceGroup](../../../aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceServiceGroup.Local.png) |




## AwsIoTAlexaVoiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

## AwsIoTAlexaVoiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

## AwsIoTAlexaVoiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q3-2021/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q3-2021/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-7.1.0.tgz: package/distribution/aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService.md <==
# AwsIoTAlexaVoiceService


```text
aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService
```

```text
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')
```



| Illustration | AwsIoTAlexaVoiceService | AwsIoTAlexaVoiceServiceCard | AwsIoTAlexaVoiceServiceGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService.png) | ![illustration for AwsIoTAlexaVoiceService](../../../aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceCard](../../../aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceServiceCard.Local.png) | ![illustration for AwsIoTAlexaVoiceServiceGroup](../../../aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceServiceGroup.Local.png) |




## AwsIoTAlexaVoiceService

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceService
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceService('AwsIoTAlexaVoiceService', 'Aws Io T Alexa Voice Service', 'an optional tech label')
@enduml
```

## AwsIoTAlexaVoiceServiceCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceCard
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceCard('AwsIoTAlexaVoiceServiceCard', 'Aws Io T Alexa Voice Service Card', 'an optional description')
@enduml
```

## AwsIoTAlexaVoiceServiceGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-q1-2022/bootstrap')

' loads the Item which embeds the element AwsIoTAlexaVoiceServiceGroup
include('aws-q1-2022/Resource/LoT/AwsIoTAlexaVoiceService')

' renders the element
AwsIoTAlexaVoiceServiceGroup('AwsIoTAlexaVoiceServiceGroup', 'Aws Io T Alexa Voice Service Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
